@@ -17,12 +17,12 @@ __all__ = [
 
 __title__ = "spark-python"
 __summary__ = "Python Bindings for Cisco Spark API"
-__uri__ = "http://github.com/kecorbin/spark-python"
+__uri__ = "http://github.com/imapex/spark-python"
 
-__version__ = "0.0.6"
+__version__ = "0.0.8"
 
 __author__ = "Cisco Systems, Inc."
-__email__ = "kecorbin@cisco.com"
+__email__ = "imapex-admin@cisco.com"
 
 __license__ = "Apache License, Version 2.0"
-__copyright__ = "2015 %s" % __author__
+__copyright__ = "2016 %s" % __author__
